@@ -17,13 +17,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.23 1999/08/25 11:07:30 gobry Exp $
+# $Id: Base.py,v 1.24 1999/08/26 11:16:00 gobry Exp $
 
 from string import *
 import re
 import Pyblio.Help
 from types import *
 
+from Pyblio import Config
+
 """ This Module contains the base classes one might want to inherit
 from in order to provide a new database format """
 
@@ -541,6 +543,12 @@ class Reference (DataBase):
 
 		return r
 
+	def new_entry (self):
+		if self.has_property ('add'):
+			return self.bases () [0].new_entry ()
+
+		return DataBase.new_entry (self)
+		
 	def update (self):
 		# if we have any edition property
 		if self.has_property ('edit') or self.has_property ('add') or\
@@ -562,6 +570,7 @@ class Reference (DataBase):
 			
 			if test.match (self [k]):
 				r.add (self.base (entry), k)
-				
+
+		r.properties = self.properties
 		return r
 
