@@ -18,9 +18,13 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: stringutils.c,v 1.10 1999/05/10 11:51:13 gobry Exp $
+ $Id: stringutils.c,v 1.11 1999/08/04 09:37:21 gobry Exp $
 */
 
+#ifdef HAVE_CONFIG_H
+#include "pyblioconf.h"
+#endif
+
 #include "bibtex.h"
 
 static GList * strings = NULL;
